
margin = {top: 20, right: 20, bottom: 30, left: 50}
width = 960 - margin.left - margin.right
height = 500 - margin.top - margin.bottom

svg = d3.select('#scales svg')
		.attr('width', width + margin.left + margin.right)
		.attr('height', height + margin.top + margin.bottom)
	.append('g')
		.attr('transform', 'translate(' + margin.left + ',' + margin.top + ')')

x = d3.scale.linear().range([0, width])
y = d3.scale.linear().range([height, 0])

line = d3.svg.line()
	.x((d) -> x(d.x))
	.y((d) -> y(d.y))

xs = d3.range(1, 100)
[xse, yse] = [d3.extent(xs), [0, 100]]
x.domain(xse)
y.domain(yse)

funcs =
	log: d3.scale.log()
	sqrt: d3.scale.sqrt()
	linear: d3.scale.linear()
	'pow(2)': d3.scale.pow().exponent(2)
	'pow(4)': d3.scale.pow().exponent(4)
	'pow(10)': d3.scale.pow().exponent(10)
	'pow(0.2)': d3.scale.pow().exponent(0.2)

for func in d3.values(funcs)
	func.range(yse).domain(xse)

colors = d3.scale.category20()

svg.selectAll('path')
		.data(d3.entries(funcs))
	.enter().append('path')
		.datum((d) -> ({x: v, y: d.value(v), name: d.key} for v in xs))
		.attr('class', 'data')
		.attr('d', line)
		.style('stroke', (d) -> colors(d[0].name))

d3.select('#scales .legend').selectAll('li')
		.data(d3.keys(funcs))
	.enter().append('li')
		.text((d) -> d)
		.style('color', (d) -> colors(d))

svg.append('g')
	.attr('class', 'x axis')
	.attr('transform', 'translate(0,' + height + ')')
	.call(d3.svg.axis().scale(x).orient('bottom'))

svg.append('g')
		.attr('class', 'y axis')
		.call(d3.svg.axis().scale(y).orient('left'))
